# Changelog

<!--next-version-placeholder-->

## v0.139.0 (2022-02-25)
### Feature
* Improve changelog generation
 ([`5761abd`](https://github.com/yandex-cloud/python-sdk/commit/5761abd71a65abcc9b1383bfbb8a5021fdd0323c))
* Regenerate proto
 ([`bee7793`](https://github.com/yandex-cloud/python-sdk/commit/bee7793a76617a41ca8433e40422be69dba1247e))

## v0.138.0 (2022-02-25)
### Feature
* Fix deps installation
 ([`6fad07f`](https://github.com/yandex-cloud/python-sdk/commit/6fad07fd9025ce6731082b4ec3f53d3b3a313b07))

## v0.137.0 (2022-02-25)
### Feature
* Add codestyle validating command + CI check ([`cd1afc5`](https://github.com/yandex-cloud/python-sdk/commit/cd1afc5edf358bf5ed8c7ade14d9789718b60b29))
* Add mccabe (cyclomatic complexity) plugin for flake8
 ([`84d6ec6`](https://github.com/yandex-cloud/python-sdk/commit/84d6ec6f2b07332e13b88e878975dcdaae9fe3df))
* Add PEP-8 check + fix warnings
 ([`1318ce4`](https://github.com/yandex-cloud/python-sdk/commit/1318ce47ba74f047a434f1cb66eb8a9d8ffe57df))

## v0.136.0 (2022-02-25)
### Feature
* Configure code generation through github actions
 ([`bb1509f`](https://github.com/yandex-cloud/python-sdk/commit/bb1509fad56551b0fca1a1afa68c91e4920c4515))

## v0.135.0 (2022-02-24)
### Feature
* Cleanup changelog ([`c635255`](https://github.com/yandex-cloud/python-sdk/commit/c63525586e85a7e752b5792ce73b8d2bc3e5a450))

## v0.134.0 (2022-02-24)
### Feature
* Release via github actions ([`9222567`](https://github.com/yandex-cloud/python-sdk/commit/92225671e201543711638cede06a818629cace85))
